/************
 * Pathbars *
 ************/

.path-bar .button {
  @include button(undecorated);
  padding: 4px 8px;
  color: w_color(text);
  &:hover {border-color: b_color(hover); }
  &:active, &:checked {
    background-color: $border_color;
    }
  &:first-child { padding-left: 8px; }
  &:last-child { padding-right: 8px; }
  &:only-child {
    padding-left: 12px;
    padding-right: 12px;
  }

  // the following is for spacing the icon and the label inside the home button
  .label:last-child { padding-left: 2px; }
  .label:first-child { padding-right: 2px; }
  .label:only-child { padding-right: 0; padding-left: 0; }
  GtkImage { padding-top: 1px; }
}
