/************
 * Toolbars *
 ************/
.toolbar,
.primary-toolbar {
  -GtkWidget-window-dragging: true;
  padding: 4px;
  background-color: w_color(normal);
  &:backdrop {
    background-color: backdrop(w_color(normal));
    box-shadow: none;
  }
  .osd &, &.osd {
    padding: 13px;
    border: none;
    border-radius: $r;
    background-color: w_color(normal);
    &:backdrop {
      border-color: backdrop($border_color);
      background-color: backdrop(w_color(normal));
      box-shadow: none;
    }
  }
}

//searchbar, location-bar & inline-toolbar
.inline-toolbar {
  @extend .toolbar;
  @extend %inset-bar;
  border-width: 0px 0px 1px 0px;
  padding: 3px;
  border-radius: 0;
}
.search-bar, .location-bar {
  @extend .toolbar;
  @extend %inset-bar;
  border-width: 0px 0px 1px 0px;
  padding: 3px;
}

%inset-bar {
  border-style: solid;
  border-color: $border_color;
  text-shadow: none;
  background-color: w_color(normal);
}
