/************
 * GtkScale *
 ************/
scale {

  &.fine-tune {
    &.trough {
      margin: 8px;
      border-radius: $r;
    }
  }

  slider {
    min-width: 18px;
    min-height: 18px;
    background-color: b_color(normal);
    border: 1px solid $border_color;
    border-radius: 50%;
    box-shadow: none;
    margin: -9px;
    &:hover {
      border-style: solid;
  	  border-width: 2px;
      border-color: b_color(hover);
      border-radius: 50%; // needed for double marks scales
      &:backdrop {
        background-color: backdrop(b_color(normal));
        border-color: backdrop(b_color(hover));
      }
    }
    &:disabled {
      border-style: solid; // needed for double marks scales or they'll get
      border-radius: 50%;  // overridden
      background-color: alpha2solid(insensitive(b_color(normal)),w_color(normal));
      border-color: insensitive($border_color);
      &:backdrop {
        background-color: alpha2solid(backdrop(insensitive(b_color(normal))),w_color(normal));
        border-color: backdrop(insensitive($border_color));
      }
    }
    &:active {
      border: 2px solid b_color(active);
      &:backdrop {
        background-color: backdrop(b_color(normal));
        border-color: backdrop(b_color(active));
      }
    }
    &:backdrop {
      background-color: backdrop(b_color(normal));
      border-color: backdrop($border_color);
    }
  }
  trough {
    min-width: 6px;
    min-height: 6px;
    margin: 9px;
    border: 0px solid;
    border-radius: $r;
    background-color: $trough_color;
    box-shadow: none;

    &:disabled, &.vertical:disabled {
      border-color: insensitive($trough_color);
      background-color: insensitive($trough_color);
      box-shadow: none;
      &:backdrop {
        background-color: backdrop(insensitive($trough_color));
        border-color: backdrop(insensitive($trough_color));
      }
    }
    &:backdrop {
      background-color: backdrop($trough_color);
      border-color: backdrop($trough_color);
    }
  }
  highlight {
    border: 0px solid;
    border-radius: 3px;
    background-color: s_color(normal);
    border-color: s_color(normal);
    &.vertical {
      background-color: s_color(normal);
      border-color: s_color(normal);
    }
    &:disabled { background-color: insensitive(s_color(normal));}
    &:backdrop {
      background-color: backdrop(s_color(backdrop));
      border-color: backdrop(s_color(backdrop));
      &:disabled {background-color: backdrop(insensitive(s_color(normal)));}
    }
  }
}
