//apps rely on some named colors to be exported
/* GTK NAMED COLORS
   ----------------
   use responsibly! */

// Sass thinks we're using the colors in the variables as strings and may shoot
// warning, it's innocuous and can be defeated by using "" + $var
/*
widget text/foreground color */
@define-color theme_fg_color #{"" + w_color(text)};

/*
text color for entries, views and content in general */
@define-color theme_text_color #{"" +v_color(text)};

/*
widget base background color */
@define-color theme_bg_color #{"" +w_color(normal)};

/*
text widgets and the like base background color */
@define-color theme_base_color #{"" +v_color(normal)};

/*
base background color of selections */
@define-color theme_selected_bg_color #{"" +s_color(normal)};

/*
text/foreground color of selections */
@define-color theme_selected_fg_color #{"" +s_color(text)};

/*
base background color of insensitive widgets */
@define-color insensitive_bg_color #{"" +insensitive(w_color(normal))};

/*
text foreground color of insensitive widgets */
@define-color insensitive_fg_color #{"" +insensitive(w_color(text))};

/*
insensitive text widgets and the like base background color */
@define-color insensitive_base_color #{"" +insensitive(v_color(text))};

/*
widget text/foreground color on backdrop windows */
@define-color theme_unfocused_fg_color #{"" +backdrop(w_color(text))};

/*
text color for entries, views and content in general on backdrop windows */
@define-color theme_unfocused_text_color #{"" +backdrop(v_color(text))};

/*
widget base background color on backdrop windows */
@define-color theme_unfocused_bg_color #{"" +backdrop(w_color(normal))};

/*
text widgets and the like base background color on backdrop windows */
@define-color theme_unfocused_base_color #{"" +backdrop(v_color(normal))};

/*
base background color of selections on backdrop windows */
@define-color theme_unfocused_selected_bg_color #{"" +backdrop(s_color(backdrop))};

/*
text/foreground color of selections on backdrop windows */
@define-color theme_unfocused_selected_fg_color #{"" + backdrop(s_color(text))};

/*
widgets main borders color */
@define-color borders #{"" +$border_color};

/*
widgets main borders color on backdrop windows */
@define-color unfocused_borders #{"" +backdrop($border_color)};

/*
widgets main borders color insensitive */
@define-color insensitive_borders #{"" +insensitive($border_color)};
/*
these are pretty self explicative */
@define-color warning_color #{"" +$warning_color};
@define-color error_color #{"" +$error_color};
@define-color success_color #{"" +$success_color};

//@define-color destructive_color #{$destructive_color}

//WM

// $_wm_highlight: if($variant=='light', $top_hilight,  // Sass gets mad if this is
//                   transparentize(black,1));          // done directly in the
//                                                      // color definition
//
// /*
// these colors are exported for the window manager and shouldn't be used in applications,
// read if you used those and something break with a version upgrade you're on your own... */
// @define-color wm_title #{$titlebar_fg_color};
// @define-color wm_unfocused_title #{$backdrop_fg_color};
// @define-color wm_highlight #{"" + $_wm_highlight};
// @define-color wm_borders_edge #{"" + $borders_edge};
//
// @define-color wm_bg_a #{$titlebar_bg_color};
// @define-color wm_bg_b #{$titlebar_bg_color};
//
// @define-color wm_shadow alpha(black, 0.35);
// @define-color wm_border alpha(black, 0.18);
//
// @define-color wm_button_hover_color_a shade(#{$bg_color}, 1.3);
// @define-color wm_button_hover_color_b #{$bg_color};
// @define-color wm_button_active_color_a shade(#{$bg_color}, 0.85);
// @define-color wm_button_active_color_b shade(#{$bg_color}, 0.89);
// @define-color wm_button_active_color_c shade(#{$bg_color}, 0.9);

//FIXME this is really an API

@define-color content_view_bg #{"" + v_color(normal)};
